History
=======


0.13.0 (24-02-2020)
-------------------

* Add Subject class
* Add random blur transform
* Add lambda transform
* Add random patches swapping transform
* Add MRI k-space ghosting artefact augmentation


0.12.0 (21-01-2020)
-------------------

* Add ToCanonical transform
* Add CenterCropOrPad transform


0.11.0 (15-01-2020)
-------------------

* Add Resample transform


0.10.0 (15-01-2020)
-------------------

* Add Pad transform
* Add Crop transform


0.9.0 (14-01-2020)
------------------

* Add CLI tool to transform an image from file


0.8.0 (11-01-2020)
------------------

* Add Image class


0.7.0 (02-01-2020)
------------------

* Make transforms use PyTorch tensors consistently


0.6.0 (02-01-2020)
------------------

* Add support for NRRD


0.5.0 (01-01-2020)
------------------

* Add bias field transform


0.4.0 (29-12-2019)
------------------

* Add MRI k-space motion artefact augmentation


0.3.0 (21-12-2019)
------------------

* Add Rescale transform
* Add support for multimodal data and missing modalities


0.2.0 (2019-12-06)
------------------

* First release on PyPI.
